aboutsummaryrefslogtreecommitdiff
path: root/example/reader_util.c
diff options
context:
space:
mode:
Diffstat (limited to 'example/reader_util.c')
-rw-r--r--example/reader_util.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/example/reader_util.c b/example/reader_util.c
index 2564f4ffd..82251e85d 100644
--- a/example/reader_util.c
+++ b/example/reader_util.c
@@ -1164,8 +1164,8 @@ static struct ndpi_proto packet_processing(struct ndpi_workflow * workflow,
if(enough_packets || (flow->detected_protocol.app_protocol != NDPI_PROTOCOL_UNKNOWN)) {
if((!enough_packets)
&& (flow->detected_protocol.master_protocol == NDPI_PROTOCOL_TLS)
- && (flow->ndpi_flow->protos.stun_ssl.ssl.ja3_server[0] == '\0'))
- ; /* Wait for JA3S certificate */
+ && (!flow->ndpi_flow->l4.tcp.tls_srv_cert_fingerprint_processed))
+ ; /* Wait for certificate fingerprint */
else {
/* New protocol detected or give up */
flow->detection_completed = 1;